@@ -13,9 +13,6 @@ NO_TESTS=""
 RET_VAL=""
 [ -d ${BUILD_DIR} ] || mkdir ${BUILD_DIR}
 
-[[ "${MSYSTEM}" =~ "MINGW" ]] && IS_MSYS2_BUILD="Y"
-[ -n "${IS_MSYS2_BUILD}" ] && DEFAULT_BUILD_TYPE="Release" || DEFAULT_BUILD_TYPE="Debug"
-
 f_any_argument_matches () {
   if [ "${ARG1_VAL_LOWER}" == "$1" ] || [ "${ARG2_VAL_LOWER}" == "$1" ] || [ "${ARG3_VAL_LOWER}" == "$1" ]
   then
@@ -38,14 +35,7 @@ then
   exit 0
 fi
 
-f_any_argument_matches "debug" "dbg"
-if [ -n "${RET_VAL}" ]
-then
-  CMAKE_BUILD_TYPE="Debug"
-else
-  f_any_argument_matches "release" "rel"
-  [ -n "${RET_VAL}" ] && CMAKE_BUILD_TYPE="Release" || CMAKE_BUILD_TYPE=${DEFAULT_BUILD_TYPE}
-fi
+[[ "${MSYSTEM}" =~ "MINGW" ]] && IS_MSYS2_BUILD="Y"
 
 f_any_argument_matches "notests" "notest"
 [ -n "${RET_VAL}" ] && NO_TESTS="Y"
@@ -62,6 +52,24 @@ f_any_argument_matches "appimage" "appimg"
 f_any_argument_matches "bundledspdlog" "bundledfmt" "bundledspdfmt"
 [ -n "${RET_VAL}" ] && BUNDLED_SPDLOG_FMT="Y"
 
+if [ -n "${MAKE_DEB}" ] || [ -n "${MAKE_RPM}" ] || [ -n "${MAKE_APPIMAGE}" ]
+then
+  DEFAULT_BUILD_TYPE="Release"
+else
+  DEFAULT_BUILD_TYPE="Debug"
+fi
+
+f_any_argument_matches "debug" "dbg"
+if [ -n "${RET_VAL}" ]
+then
+  CMAKE_BUILD_TYPE="Debug"
+else
+  f_any_argument_matches "release" "rel"
+  [ -n "${RET_VAL}" ] && CMAKE_BUILD_TYPE="Release" || CMAKE_BUILD_TYPE=${DEFAULT_BUILD_TYPE}
+fi
+
+echo "CMAKE_BUILD_TYPE=${CMAKE_BUILD_TYPE}"
+
 if [ -f /etc/lsb-release ]
 then
   DISTRIB_ID="$(grep DISTRIB_ID /etc/lsb-release | awk -F= '{print $2}')"
@@ -69,7 +77,12 @@ then
 elif [ -f /etc/debian_version ]
 then
   DISTRIB_ID="Debian"
-  DISTRIB_RELEASE="$(cat /etc/debian_version | awk -F. '{print $1}' | tr -d '\n')"
+    if grep -q sid /etc/debian_version
+    then
+      DISTRIB_RELEASE="$(cat /etc/debian_version | awk -F/ '{print $1}' | tr -d '\n')"
+    else
+      DISTRIB_RELEASE="$(cat /etc/debian_version | awk -F. '{print $1}' | tr -d '\n')"
+    fi
 elif [ -f /etc/fedora-release ]
 then
   DISTRIB_ID="Fedora"
@@ -80,8 +93,6 @@ then
   DISTRIB_RELEASE="$(grep ^VERSION_ID= /etc/os-release | awk -F\" '{print $2}')"
 fi
 
-echo "CMAKE_BUILD_TYPE=${CMAKE_BUILD_TYPE}"
-
 if [ -n "${DISTRIB_ID}" ] && [ -n "${DISTRIB_RELEASE}" ]
 then
   echo "Building on ${DISTRIB_ID} ${DISTRIB_RELEASE}"
@@ -133,8 +144,7 @@ then
   [ -f linuxdeploy-plugin-gtk.sh ] || wget -c "https://raw.githubusercontent.com/linuxdeploy/linuxdeploy-plugin-gtk/master/linuxdeploy-plugin-gtk.sh"
   [ -f linuxdeploy-x86_64.AppImage ] || wget -c "https://github.com/linuxdeploy/linuxdeploy/releases/download/continuous/linuxdeploy-x86_64.AppImage"
   [ -f TinyTeX-1-v2022.04.04.tar.xz ] || wget -c "https://www.giuspen.net/software/TinyTeX-1-v2022.04.04.tar.xz"
-  chmod +x linuxdeploy-plugin-gtk.sh
-  chmod +x linuxdeploy-x86_64.AppImage
+  chmod +x linuxdeploy-x86_64.AppImage linuxdeploy-plugin-gtk.sh
   rm -rf AppDir
   mkdir AppDir
   tar xf TinyTeX-1-v2022.04.04.tar.xz -C AppDir/
