@@ -82,12 +82,36 @@ void CtActions::file_save_as()
         fileSelArgs.filter_name = _("CherryTree File");
         std::string fileExtension = CtMiscUtil::get_doc_extension(storageSelArgs.ctDocType, storageSelArgs.ctDocEncrypt);
         fileSelArgs.filter_pattern.push_back(std::string{CtConst::CHAR_STAR}+fileExtension);
+        fileSelArgs.overwrite_confirmation = false; // as not supported for the multifile, we do in both cases elsewhere
         filepath = CtDialogs::file_save_as_dialog(_pCtMainWin, fileSelArgs);
     }
     if (filepath.empty()) {
         return;
     }
     CtMiscUtil::filepath_extension_fix(storageSelArgs.ctDocType, storageSelArgs.ctDocEncrypt, filepath);
+    if (Glib::file_test(filepath, Glib::FILE_TEST_EXISTS)) {
+        // overwrite confirmation here
+        std::string message;
+        if (Glib::file_test(filepath, Glib::FILE_TEST_IS_DIR)) {
+            // if the output is multifile and the folder is empty, then we are good, otherwise we need to ask
+            if (CtDocType::MultiFile != storageSelArgs.ctDocType or
+                fs::get_dir_entries(filepath).size())
+            {
+                message = str::format(_("A folder '%s' already exists in '%s'.\n<b>Do you want to remove it?</b>"),
+                    str::xml_escape(Glib::path_get_basename(filepath)), str::xml_escape(Glib::path_get_dirname(filepath)));
+            }
+        }
+        else {
+            message = str::format(_("A file '%s' already exists in '%s'.\n<b>Do you want to remove it?</b>"),
+                str::xml_escape(Glib::path_get_basename(filepath)), str::xml_escape(Glib::path_get_dirname(filepath)));
+        }
+        if (message.size()) {
+            if (not CtDialogs::question_dialog(message, *_pCtMainWin)) {
+                return;
+            }
+            (void)fs::remove_all(filepath);
+        }
+    }
     _pCtMainWin->file_save_as(filepath, storageSelArgs.ctDocType, storageSelArgs.password);
 }
 
@@ -157,6 +181,7 @@ void CtActions::preferences_import()
     _pCtConfig->menubarInTitlebar = ctConfigImported.menubarInTitlebar;
     _pCtConfig->showNodeNameHeader = ctConfigImported.showNodeNameHeader;
     _pCtConfig->nodesOnNodeNameHeader = ctConfigImported.nodesOnNodeNameHeader;
+    _pCtConfig->maxMatchesInPage = ctConfigImported.maxMatchesInPage;
     _pCtConfig->toolbarIconSize = ctConfigImported.toolbarIconSize;
     _pCtConfig->currColors['f'] = ctConfigImported.currColors['f'];
     _pCtConfig->currColors['b'] = ctConfigImported.currColors['b'];
@@ -172,6 +197,7 @@ void CtActions::preferences_import()
     _pCtConfig->cherryWrapWidth = ctConfigImported.cherryWrapWidth;
     _pCtConfig->treeClickFocusText = ctConfigImported.treeClickFocusText;
     _pCtConfig->treeClickExpand = ctConfigImported.treeClickExpand;
+    _pCtConfig->treeTooltips = ctConfigImported.treeTooltips;
     _pCtConfig->syntaxHighlighting = ctConfigImported.syntaxHighlighting;
     _pCtConfig->autoSynHighl = ctConfigImported.autoSynHighl;
     _pCtConfig->rtStyleScheme = ctConfigImported.rtStyleScheme;
@@ -277,15 +303,38 @@ void CtActions::preferences_import()
         _pCtConfig->update_user_style(n);
     }
     _pCtConfig->toolbarUiList = ctConfigImported.toolbarUiList;
-    _pCtConfig->systrayOn = ctConfigImported.systrayOn;
+    if (ctConfigImported.systrayOn != _pCtConfig->systrayOn) {
+        // this we have to apply immediately because it affects the way the app quits
+        if (ctConfigImported.systrayOn) {
+            _pCtMainWin->get_status_icon()->set_visible(true);
+#if defined(_WIN32)
+            _pCtConfig->systrayOn = true; // windows does support the systray
+#else // !_WIN32
+            _pCtConfig->systrayOn = CtDialogs::question_dialog(_("Has the System Tray appeared on the panel?"), *_pCtMainWin);
+#endif // !_WIN32
+            if (_pCtConfig->systrayOn) {
+                _pCtMainWin->signal_app_apply_for_each_window([](CtMainWin* win) { win->menu_set_visible_exit_app(true); });
+            }
+            else {
+                CtDialogs::warning_dialog(_("Your system does not support the System Tray"), *_pCtMainWin);
+            }
+        }
+        else {
+            _pCtConfig->systrayOn = false;
+            _pCtMainWin->get_status_icon()->set_visible(false);
+            _pCtMainWin->signal_app_apply_for_each_window([](CtMainWin* win) { win->menu_set_visible_exit_app(false); });
+        }
+    }
     _pCtConfig->startOnSystray = ctConfigImported.startOnSystray;
-    _pCtConfig->useAppInd = ctConfigImported.useAppInd;
     _pCtConfig->autosaveOn = ctConfigImported.autosaveOn;
     _pCtConfig->autosaveVal = ctConfigImported.autosaveVal;
     _pCtConfig->bookmarksInTopMenu = ctConfigImported.bookmarksInTopMenu;
+    _pCtConfig->menusTooltips = ctConfigImported.menusTooltips;
+    _pCtConfig->toolbarTooltips = ctConfigImported.toolbarTooltips;
     _pCtConfig->checkVersion = ctConfigImported.checkVersion;
     _pCtConfig->wordCountOn = ctConfigImported.wordCountOn;
     _pCtConfig->reloadDocLast = ctConfigImported.reloadDocLast;
+    _pCtConfig->rememberRecentDocs = ctConfigImported.rememberRecentDocs;
     _pCtConfig->winTitleShowDocDir = ctConfigImported.winTitleShowDocDir;
     _pCtConfig->nodeNameHeaderShowFullPath = ctConfigImported.nodeNameHeaderShowFullPath;
     _pCtConfig->modTimeSentinel = ctConfigImported.modTimeSentinel;
