@@ -32,7 +32,7 @@
 
 void CtActions::_find_init()
 {
-    _s_state.match_store = CtMatchDialogStore::create();
+    _s_state.match_store = CtMatchDialogStore::create(_pCtConfig->maxMatchesInPage);
     std::time_t curr_time = std::time(nullptr);
     std::time_t yesterday_time = curr_time - 86400; //24*60*60
     _s_options.ts_cre_after  = {yesterday_time, false};
@@ -85,8 +85,7 @@ void CtActions::find_in_selected_node()
     _pCtMainWin->user_active() = false;
 
     if (all_matches) {
-        _s_state.match_store->clear();
-        _s_state.match_store->saved_path.clear();
+        _s_state.match_store->deep_clear();
         _s_state.all_matches_first_in_node = true;
     }
     CtTreeIter::clear_hit_exclusion_from_search();
@@ -108,8 +107,7 @@ void CtActions::find_in_selected_node()
                                      str::format(_("<b>The pattern '%s' was not found</b>"), str::xml_escape(pattern)));
     }
     else if (all_matches) {
-        _s_state.match_dialog_title = "'" + _s_options.str_find + "'  -  " + std::to_string(_s_state.matches_num) + CtConst::CHAR_SPACE + _("Matches");
-        CtDialogs::match_dialog(_s_state.match_dialog_title, _pCtMainWin, _s_state.match_store);
+        CtDialogs::match_dialog(_s_options.str_find, _pCtMainWin, _s_state);
     }
     else if (_s_options.iterative_dialog) {
         CtDialogs::iterated_find_dialog(_pCtMainWin, _s_state);
@@ -183,8 +181,7 @@ void CtActions::find_in_multiple_nodes()
     }
     _s_state.matches_num = 0;
     if (all_matches) {
-        _s_state.match_store->clear();
-        _s_state.match_store->saved_path.clear();
+        _s_state.match_store->deep_clear();
     }
     CtTreeIter::clear_hit_exclusion_from_search();
 
@@ -206,6 +203,11 @@ void CtActions::find_in_multiple_nodes()
     while (node_iter) {
         _s_state.all_matches_first_in_node = true;
         CtTreeIter ct_node_iter = ctTreeStore.to_ct_tree_iter(node_iter);
+        Glib::RefPtr<Gsv::Buffer> rTextBuffer = ct_node_iter.get_node_text_buffer();
+        if (not rTextBuffer) {
+            CtDialogs::error_dialog(str::format(_("Failed to retrieve the content of the node '%s'"), ct_node_iter.get_node_name()), *_pCtMainWin);
+            break;
+        }
         while (_parse_given_node_content(ct_node_iter, re_pattern, forward, first_fromsel, all_matches)) {
             ++_s_state.matches_num;
             if (not all_matches or ctStatusBar.is_progress_stop()) break;
@@ -252,8 +254,7 @@ void CtActions::find_in_multiple_nodes()
     }
     else {
         if (all_matches) {
-            _s_state.match_dialog_title = "'" + _s_options.str_find + "'  -  " + std::to_string(_s_state.matches_num) + CtConst::CHAR_SPACE + _("Matches");
-            CtDialogs::match_dialog(_s_state.match_dialog_title, _pCtMainWin, _s_state.match_store);
+            CtDialogs::match_dialog(_s_options.str_find, _pCtMainWin, _s_state);
         }
         else {
             ctTreeView.set_cursor_safe(last_iterated_node);
@@ -304,8 +305,10 @@ void CtActions::replace_in_selected_node()
 {
     if (not _is_there_selected_node_or_error()) return;
     _s_state.replace_active = true;
+    _s_state.replace_subsequent = false;
     find_in_selected_node();
     _s_state.replace_active = false;
+    _s_state.replace_subsequent = false;
 }
 
 // Replace the pattern in all the Tree Nodes
@@ -313,8 +316,10 @@ void CtActions::replace_in_multiple_nodes()
 {
     if (not _is_tree_not_empty_or_error()) return;
     _s_state.replace_active = true;
+    _s_state.replace_subsequent = false;
     find_in_multiple_nodes();
     _s_state.replace_active = false;
+    _s_state.replace_subsequent = false;
 }
 
 // Continue the previous replace (a_node/in_selected_node/in_all_nodes)
@@ -330,7 +335,7 @@ void CtActions::replace_again()
 // Restore AllMatchesDialog
 void CtActions::find_allmatchesdialog_restore()
 {
-    CtDialogs::match_dialog(_s_state.match_dialog_title, _pCtMainWin, _s_state.match_store);
+    CtDialogs::match_dialog(_s_options.str_find, _pCtMainWin, _s_state);
 }
 
 // Returns True if pattern was found, False otherwise
@@ -380,6 +385,11 @@ bool CtActions::_parse_given_node_content(CtTreeIter node_iter,
             while (child_iter and not _pCtMainWin->get_status_bar().is_progress_stop()) {
                 _s_state.all_matches_first_in_node = true;
                 CtTreeIter ct_node_iter = ctTreeStore.to_ct_tree_iter(child_iter);
+                Glib::RefPtr<Gsv::Buffer> rTextBuffer = ct_node_iter.get_node_text_buffer();
+                if (not rTextBuffer) {
+                    CtDialogs::error_dialog(str::format(_("Failed to retrieve the content of the node '%s'"), ct_node_iter.get_node_name()), *_pCtMainWin);
+                    break;
+                }
                 while (_parse_given_node_content(ct_node_iter, re_pattern, forward, first_fromsel, all_matches)) {
                     _s_state.matches_num += 1;
                     if (not all_matches or _pCtMainWin->get_status_bar().is_progress_stop()) break;
@@ -473,7 +483,7 @@ bool CtActions::_parse_node_content_iter(const CtTreeIter& tree_iter,
     Gtk::TextIter start_iter;
     if ((first_fromsel and first_node) or (all_matches and not _s_state.all_matches_first_in_node)) {
         gint64 node_id = tree_iter.get_node_id();
-        start_iter = _get_inner_start_iter(text_buffer, forward, node_id);
+        start_iter = _get_inner_start_iter(text_buffer, forward, all_matches, node_id);
     }
     else {
         start_iter = forward ? text_buffer->begin() : text_buffer->end();
@@ -495,10 +505,18 @@ bool CtActions::_parse_node_content_iter(const CtTreeIter& tree_iter,
 }
 
 // Get start_iter when not at beginning or end
-Gtk::TextIter CtActions::_get_inner_start_iter(Glib::RefPtr<Gtk::TextBuffer> text_buffer, bool forward, const gint64& node_id)
+Gtk::TextIter CtActions::_get_inner_start_iter(Glib::RefPtr<Gtk::TextBuffer> text_buffer,
+                                               const bool forward,
+                                               const bool all_matches,
+                                               const gint64& node_id)
 {
     Gtk::TextIter min_iter, max_iter;
-    if (text_buffer->get_has_selection()) {
+    if (all_matches and _s_state.latest_match_offsets.first >= 0 and _s_state.latest_match_offsets.second >= 0) {
+        const int newline_trick_offset = _s_state.newline_trick ? 1 : 0;
+        min_iter = text_buffer->get_iter_at_offset(_s_state.latest_match_offsets.first + newline_trick_offset);
+        max_iter = text_buffer->get_iter_at_offset(_s_state.latest_match_offsets.second + newline_trick_offset);
+    }
+    else if (text_buffer->get_has_selection()) {
         text_buffer->get_selection_bounds(min_iter, max_iter);
     }
     else {
@@ -585,7 +603,6 @@ bool CtActions::_find_pattern(CtTreeIter tree_iter,
     }
 
     int start_offset = start_iter.get_offset();
-    // # start_offset -= self.get_num_objs_before_offset(text_buffer, start_offset)
     std::pair<int, int> match_offsets{-1, -1};
     if (forward) {
         Glib::MatchInfo match_info;
@@ -609,7 +626,7 @@ bool CtActions::_find_pattern(CtTreeIter tree_iter,
     }
 
     std::pair<int,int> obj_match_offsets{-1, -1};
-    std::string obj_content;
+    Glib::ustring obj_content;
     if (not _s_state.replace_active) {
         obj_match_offsets = _check_pattern_in_object_between(tree_iter, text_buffer, re_pattern,
             start_iter.get_offset(), match_offsets.first, forward, obj_content);
@@ -624,60 +641,61 @@ bool CtActions::_find_pattern(CtTreeIter tree_iter,
     int final_start_offset = match_offsets.first + num_objs;
     int final_delta_offset = match_offsets.second - match_offsets.first;
 
-    if (not _pCtMainWin->curr_tree_iter() or _pCtMainWin->curr_tree_iter().get_node_id() != tree_iter.get_node_id()) {
-        _pCtMainWin->get_tree_view().set_cursor_safe(tree_iter);
+    if (not all_matches) {
+        if (not _pCtMainWin->curr_tree_iter() or _pCtMainWin->curr_tree_iter().get_node_id() != tree_iter.get_node_id()) {
+            _pCtMainWin->get_tree_view().set_cursor_safe(tree_iter);
+        }
+        _pCtMainWin->get_text_view().set_selection_at_offset_n_delta(final_start_offset, final_delta_offset);
     }
-    CtTextView& ctTextView = _pCtMainWin->get_text_view();
-    ctTextView.set_selection_at_offset_n_delta(final_start_offset, final_delta_offset);
 
-    auto mark_insert = text_buffer->get_insert();
-    Gtk::TextIter iter_insert = text_buffer->get_iter_at_mark(mark_insert);
     const int newline_trick_offset = _s_state.newline_trick ? 1 : 0;
     _s_state.latest_match_offsets.first = match_offsets.first + num_objs - newline_trick_offset;
     _s_state.latest_match_offsets.second = match_offsets.second + num_objs - newline_trick_offset;
-    Gtk::TreeIter iterAllMatchesRow;
+    CtMatchRowData* pCtMatchRowData{nullptr};
     if (all_matches) {
         const gint64 node_id = tree_iter.get_node_id();
         const Glib::ustring node_name = tree_iter.get_node_name();
         const std::string node_hier_name = CtMiscUtil::get_node_hierarchical_name(tree_iter, " << ", false, false);
-        const std::string line_content = obj_match_offsets.first != -1 ? obj_content : _get_line_content(text_buffer, iter_insert);
+        const Glib::ustring line_content = obj_match_offsets.first != -1 ?
+            obj_content : _get_line_content(text_buffer, _s_state.latest_match_offsets.second);
         int line_num = text_buffer->get_iter_at_offset(_s_state.latest_match_offsets.first).get_line();
         if (not _s_state.newline_trick) { line_num += 1; }
         const Glib::ustring text_tags = tree_iter.get_node_tags();
-        iterAllMatchesRow = _s_state.match_store->add_row(node_id,
-                                                          text_tags.empty() ? node_name : node_name + "\n [" +  _("Tags") + _(": ") + text_tags + "]",
-                                                          str::xml_escape(node_hier_name),
-                                                          _s_state.latest_match_offsets.first,
-                                                          _s_state.latest_match_offsets.second,
-                                                          line_num,
-                                                          line_content);
+        pCtMatchRowData = _s_state.match_store->add_row(node_id,
+                                                        text_tags.empty() ? node_name : node_name + "\n [" +  _("Tags") + _(": ") + text_tags + "]",
+                                                        str::xml_escape(node_hier_name),
+                                                        _s_state.latest_match_offsets.first,
+                                                        _s_state.latest_match_offsets.second,
+                                                        line_num,
+                                                        line_content);
     }
     else {
-        ctTextView.scroll_to(mark_insert, CtTextView::TEXT_SCROLL_MARGIN);
+        _pCtMainWin->get_text_view().scroll_to(text_buffer->get_insert(), CtTextView::TEXT_SCROLL_MARGIN);
     }
     if (_s_state.replace_active) {
-        if (_pCtMainWin->curr_tree_iter().get_node_read_only()) return false;
-        Gtk::TextIter sel_start, sel_end;
-        text_buffer->get_selection_bounds(sel_start, sel_end);
+        if (tree_iter.get_node_read_only()) return false;
+        Gtk::TextIter sel_start = text_buffer->get_iter_at_offset(_s_state.latest_match_offsets.first + newline_trick_offset);
+        Gtk::TextIter sel_end = text_buffer->get_iter_at_offset(_s_state.latest_match_offsets.second + newline_trick_offset);
 
         Glib::ustring origin_text = sel_start.get_text(sel_end);
         Glib::ustring replacer_text = _s_options.str_replace; /* should be Glib::ustring to count symbols */
 
         // use re_pattern->replace for the cases with \n, maybe it even helps with groups
-        if (_s_options.reg_exp)
+        if (_s_options.reg_exp) {
             replacer_text = re_pattern->replace(origin_text, 0, replacer_text, static_cast<Glib::RegexMatchFlags>(0));
-
+        }
         text_buffer->erase(sel_start, sel_end);
-        text_buffer->insert_at_cursor(replacer_text);
+        text_buffer->insert(text_buffer->get_iter_at_offset(_s_state.latest_match_offsets.first + newline_trick_offset), replacer_text);
         _s_state.latest_match_offsets.second = _s_state.latest_match_offsets.first + replacer_text.size();
+        _s_state.replace_subsequent = true;
         if (all_matches) {
-            (*iterAllMatchesRow)[_s_state.match_store->columns.end_offset] = _s_state.latest_match_offsets.second;
+            pCtMatchRowData->end_offset = _s_state.latest_match_offsets.second;
         }
         else {
-            ctTextView.set_selection_at_offset_n_delta(_s_state.latest_match_offsets.first,
+            _pCtMainWin->get_text_view().set_selection_at_offset_n_delta(_s_state.latest_match_offsets.first + newline_trick_offset,
                                                        static_cast<int>(replacer_text.size()));
         }
-        _pCtMainWin->get_state_machine().update_state();
+        _pCtMainWin->get_state_machine().update_state(tree_iter);
         tree_iter.pending_edit_db_node_buff();
     }
     return true;
@@ -731,7 +749,7 @@ std::pair<int, int> CtActions::_check_pattern_in_object_between(CtTreeIter tree_
                                                                 int start_offset,
                                                                 int end_offset,
                                                                 bool forward,
-                                                                std::string& obj_content)
+                                                                Glib::ustring& obj_content)
 {
     if (not forward) start_offset -= 1;
     if (end_offset < 0) {
@@ -779,10 +797,10 @@ int CtActions::_get_num_objs_before_offset(Glib::RefPtr<Gtk::TextBuffer> text_bu
 }
 
 // Returns the Line Content Given the Text Iter
-std::string CtActions::_get_line_content(Glib::RefPtr<Gtk::TextBuffer> text_buffer, Gtk::TextIter text_iter)
+Glib::ustring CtActions::_get_line_content(Glib::RefPtr<Gtk::TextBuffer> text_buffer, const int match_end_offset)
 {
-    auto line_start = text_iter;
-    auto line_end = text_iter;
+    Gtk::TextIter line_start = text_buffer->get_iter_at_offset(match_end_offset);
+    Gtk::TextIter line_end = line_start;
     if (not line_start.backward_char()) return "";
     while (line_start.get_char() != '\n')
         if (not line_start.backward_char())
@@ -792,11 +810,13 @@ std::string CtActions::_get_line_content(Glib::RefPtr<Gtk::TextBuffer> text_buff
     while (line_end.get_char() != '\n')
         if (not line_end.forward_char())
             break;
-    return text_buffer->get_text(line_start, line_end);
+    Glib::ustring line_content = text_buffer->get_text(line_start, line_end);
+    return line_content.size() <= _line_content_limit ?
+        line_content : line_content.substr(0u, _line_content_limit) + "...";
 }
 
 // Returns the First Not Empty Line Content Given the Text Buffer
-std::string CtActions::_get_first_line_content(Glib::RefPtr<Gtk::TextBuffer> text_buffer)
+Glib::ustring CtActions::_get_first_line_content(Glib::RefPtr<Gtk::TextBuffer> text_buffer)
 {
     Gtk::TextIter start_iter = text_buffer->get_iter_at_offset(0);
     while (start_iter.get_char() == '\n')
@@ -806,7 +826,9 @@ std::string CtActions::_get_first_line_content(Glib::RefPtr<Gtk::TextBuffer> tex
     while (end_iter.get_char() != '\n')
         if (not end_iter.forward_char())
             break;
-    return text_buffer->get_text(start_iter, end_iter);
+    Glib::ustring line_content = text_buffer->get_text(start_iter, end_iter);
+    return line_content.size() <= _line_content_limit ?
+        line_content : line_content.substr(0u, _line_content_limit) + "...";
 }
 
 void CtActions::_update_all_matches_progress()
