@@ -157,7 +157,7 @@ public:
     void          text_view_apply_textbuffer(CtTreeIter& treeIter, CtTextView* pTextView);
 
     void          get_node_data(const Gtk::TreeIter& treeIter, CtNodeData& nodeData);
-    void          populate_summary_info(CtSummaryInfo& summaryInfo);
+    bool          populate_summary_info(CtSummaryInfo& summaryInfo);
     unsigned      tree_clear_property_exclude_from_search();
 
     void          update_node_data(const Gtk::TreeIter& treeIter, const CtNodeData& nodeData);
@@ -205,6 +205,7 @@ public:
 
     void pending_edit_db_bookmarks();
     void pending_rm_db_nodes(const std::vector<gint64>& node_ids);
+    const char* get_node_icon(int nodeDepth, const std::string &syntax, guint32 customIconId);
 
 protected:
     Glib::RefPtr<Gdk::Pixbuf> _get_node_icon(int nodeDepth, const std::string &syntax, guint32 customIconId);
